@@ -1,4 +1,6 @@
 """context extension."""
+from typing import List, Optional
+
 import attr
 from fastapi import FastAPI
 
@@ -15,6 +17,13 @@ class ContextExtension(ApiExtension):
     https://github.com/radiantearth/stac-api-spec/blob/master/item-search/README.md#context
     """
 
+    conformance_classes: List[str] = attr.ib(
+        factory=lambda: ["https://api.stacspec.org/v1.0.0-beta.3/item-search/#context"]
+    )
+    schema_href: Optional[str] = attr.ib(
+        default="https://raw.githubusercontent.com/radiantearth/stac-api-spec/v1.0.0-beta.3/fragments/context/json-schema/schema.json"
+    )
+
     def register(self, app: FastAPI) -> None:
         """Register the extension with a FastAPI application.
 
